#!/usr/bin/env python

import os
import sys

def main():
    current_dir = os.path.dirname(os.path.abspath(__file__))
    root_dir = os.path.abspath(os.path.join(current_dir, '..'))
    if root_dir not in sys.path:
        sys.path.insert(0, root_dir)
    
    app_path = os.path.join(root_dir, 'app.py')
    
    streamlit_command = [
        'streamlit', 'run', app_path,
        '--server.fileWatcherType=none'
    ] + sys.argv[1:]
    os.execvp('streamlit', streamlit_command)

if __name__ == '__main__':
    main()



import os
import zipfile
import io
from loguru import logger

def compress_output_folder(output_folder_path, job_output_folder_name):
    # Create a ZIP file in memory
    zip_buffer = io.BytesIO()
    with zipfile.ZipFile(zip_buffer, 'w', zipfile.ZIP_DEFLATED) as zipf:
        for root, dirs, files in os.walk(output_folder_path):
            for file in files:
                file_path = os.path.join(root, file)
                arcname = os.path.relpath(file_path, start=output_folder_path)
                zipf.write(file_path, arcname)
    zip_buffer.seek(0)
    logger.debug(f"Compressed output folder: {output_folder_path}")
    return zip_buffer.getvalue()
